@@ -44,8 +44,13 @@ class WhatsAppChat(BaseChat):
         """Create an instance from a chat text file.
 
         Args:
-            filepath (str): Path to the file. It can be a local file (e.g. 'path/to/file.txt') or an URL to a hosted
-                            file (e.g. 'http://www.url.to/file.txt')
+            filepath (str): Path to the file. Accepted sources are:
+
+                * Local file, e.g. 'path/to/file.txt'.
+                * URL to a remote hosted file, e.g. 'http://www.url.to/file.txt'.
+                * Link to Google Drive file, e.g. 'gdrive://35gKKrNk-i3t05zPLyH4_P1rPdOmKW9NZ'. The format is expected
+                  to be 'gdrive://[FILE-ID]'. Note that in order to load a file from Google Drive you first need to run
+                  :func:`gdrive_init <whatstk.utils.gdrive.gdrive_init>`.
             **kwargs: Refer to the docs from
                         :func:`df_from_txt_whatsapp <whatstk.whatsapp.parser.df_from_txt_whatsapp>` for details on
                         additional arguments.
@@ -121,7 +126,7 @@ class WhatsAppChat(BaseChat):
         df = merge_chats(dfs)
         return cls(df)
 
-    def to_txt(self, filepath, hformat=None):
+    def to_txt(self, filepath, hformat=None, encoding='utf8'):
         """Export chat to a text file.
 
         Usefull to export the chat to different formats (i.e. using different hformats).
@@ -129,6 +134,9 @@ class WhatsAppChat(BaseChat):
         Args:
             filepath (str): Name of the file to export (must be a local path).
             hformat (str, optional): Header format. Defaults to '%y-%m-%d, %H:%M - %name:'.
+            encoding (str, optional): Encoding to use for UTF when reading/writing (ex. ‘utf-8’).
+                             `List of Python standard encodings
+                             <https://docs.python.org/3/library/codecs.html#standard-encodings>`_.
 
         """
         if not filepath.endswith('.txt'):
@@ -144,5 +152,5 @@ class WhatsAppChat(BaseChat):
             formatted_line = '{} {}'.format(header, text)
             lines.append(formatted_line)
         text = '\n'.join(lines)
-        with open(filepath, 'w') as f:
+        with open(r"{}".format(filepath), 'w', encoding=encoding) as f:
             f.write(text)
